====================
 json-merger v0.1.0
====================

json-merger v0.1.0 was released on TBD, 2016.

About
-----

Invenio module that is able to merge json record objects.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install json-merger==0.1.0

Documentation
-------------

   http://pythonhosted.org/json-merger/

Happy hacking and thanks for flying json-merger.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inspirehep/json-merger
|   URL: http://invenio-software.org
